# SOME DESCRIPTIVE TITLE.
# Copyright (C) YEAR Free Software Foundation, Inc.
# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
#
#, fuzzy
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
"POT-Creation-Date: 2002-04-21 16:40-0500\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=CHARSET\n"
"Content-Transfer-Encoding: 8bit\n"

#: capplet/capplet.c:93
msgid "Set the current theme."
msgstr ""

#: capplet/capplet.c:146
msgid "Desktop theme selector"
msgstr ""

#: capplet/mtm-control-list.c:129
msgid "Manage Themes..."
msgstr ""

#: capplet/mtm-control-list.c:133
msgid "Edit..."
msgstr ""

#: capplet/mtm-control-list.c:137
msgid "New..."
msgstr ""

#: capplet/mtm-selector.c:301
#, c-format
msgid "Applying theme \"%s\", please wait ..."
msgstr ""

#: capplet/mtm-view-author.c:54
msgid "Unknown"
msgstr ""

#: capplet/mtm-view-extensions-selector.c:124
msgid "Use"
msgstr ""

#: capplet/mtm-view-extensions-selector.c:124
msgid "File"
msgstr ""

#: capplet/mtm-view-extensions-selector.c:124 libbackground/applier.c:239
msgid "Type"
msgstr ""

#: libbackground/applier.c:240
msgid ""
"Type of bg_applier: BG_APPLIER_ROOT for root window or BG_APPLIER_PREVIEW "
"for preview"
msgstr ""

#: libbackground/applier.c:247
msgid "Preview Width"
msgstr ""

#: libbackground/applier.c:248
msgid "Width if applier is a preview: Defaults to 64."
msgstr ""

#: libbackground/applier.c:255
msgid "Preview Height"
msgstr ""

#: libbackground/applier.c:256
msgid "Height if applier is a preview: Defaults to 48."
msgstr ""

#: libbackground/applier.c:454
#, c-format
msgid "Could not load pixbuf \"%s\"; disabling wallpaper."
msgstr ""

#: libbackground/applier.c:533
msgid "Disabled"
msgstr ""

#: libbackground/preview-file-selection.c:193
msgid "Can't find an hbox, using a normal file selection"
msgstr ""

#: libbackground/preview-file-selection.c:198
#: plugins/background/translatable.c:8 plugins/gtk-2/gtk-config-gui.c:136
#: plugins/xmms/xmms-config-gui.c:111
msgid "Preview"
msgstr ""

#: metatheme-edit/editor-main-page.c:145
msgid ""
"Select an existing metatheme for your desktop, or create your own. To edit a "
"theme, change the settings in the following tabs, and press \"Save\"."
msgstr ""

#: metatheme-edit/editor-page.c:172
msgid "[No information available]"
msgstr ""

#: metatheme-edit/editor-shell.c:69
msgid "Metatheme"
msgstr ""

#: metatheme-edit/main.c:34
#, c-format
msgid "%s - Metatheme Editor"
msgstr ""

#: metatheme-edit/main.c:35
msgid "Unnamed"
msgstr ""

#: metatheme-edit/save.c:19
msgid ""
"Unable to save the metatheme. Please check to make sure you have write "
"permissions to the directory specified."
msgstr ""

#: metatheme-edit/save.c:125
msgid "Theme unsaved. Save before exiting?"
msgstr ""

#: plugins/background/background-plugin.c:163
msgid "Gnome Background Image"
msgstr ""

#: plugins/background/background-plugin.c:171
msgid "Background"
msgstr ""

#: plugins/background/background-plugin.c:172
msgid ""
"Your background is composed of two parts: the background image, and the "
"background pattern, which appears behind the background image."
msgstr ""

#: plugins/background/bg-config-gui.c:179
msgid "Please select a background image"
msgstr ""

#: plugins/background/bg-ext-handler.c:203
msgid "Primary Color"
msgstr ""

#: plugins/background/bg-ext-handler.c:203
msgid "Secondary Color"
msgstr ""

#: plugins/background/bg-ext-handler.c:203
msgid "Use Gradient"
msgstr ""

#: plugins/background/bg-ext-handler.c:203
msgid "Gradient Type"
msgstr ""

#: plugins/background/bg-ext-handler.c:203
msgid "Wallpaper Layout Type"
msgstr ""

#.
#. * Translatable strings file generated by Glade.
#. * Add this file to your project's POTFILES.in.
#. * DO NOT compile it as part of your application.
#.
#: plugins/background/translatable.c:7
msgid "window1"
msgstr ""

#: plugins/background/translatable.c:9
msgid "Pattern"
msgstr ""

#: plugins/background/translatable.c:10
msgid "Type:"
msgstr ""

#: plugins/background/translatable.c:11
msgid "Solid color"
msgstr ""

#: plugins/background/translatable.c:12
msgid "Vertical gradient"
msgstr ""

#: plugins/background/translatable.c:13
msgid "Horizontal gradient"
msgstr ""

#: plugins/background/translatable.c:14
msgid "Highlight color:"
msgstr ""

#: plugins/background/translatable.c:15 plugins/background/translatable.c:17
msgid "Pick a color"
msgstr ""

#: plugins/background/translatable.c:16
msgid "Primary color:"
msgstr ""

#: plugins/background/translatable.c:18
msgid "Image alignment"
msgstr ""

#: plugins/background/translatable.c:19
msgid "Tiled"
msgstr ""

#: plugins/background/translatable.c:20
msgid "Centered"
msgstr ""

#: plugins/background/translatable.c:21
msgid "Scaled"
msgstr ""

#: plugins/background/translatable.c:22
msgid "Scaled (Keep aspect ratio)"
msgstr ""

#: plugins/gtk-2/gtk-plugin.c:190
msgid "Gtk+/GNOME 2.0 widgets"
msgstr ""

#: plugins/gtk-2/gtk-plugin.c:199
msgid "Gtk"
msgstr ""

#: plugins/gtk-2/gtk-plugin.c:200
msgid ""
"Gtk widgets are the building blocks which control the overall look of "
"applications. The Gtk+ theme also controls the icons used by applications."
msgstr ""

#: plugins/gtk/gtk-plugin.c:461
msgid "Gtk+/GNOME widgets"
msgstr ""

#: plugins/gtk/gtk-plugin.c:470
msgid "Gtk (1.x)"
msgstr ""

#: plugins/gtk/gtk-plugin.c:471
msgid ""
"Gtk widgets are the building blocks which control the overall look of "
"applications. This extension only applies to older (1.x) gtk+ applications."
msgstr ""

#: plugins/nautilus/nautilus-config-gui.c:169
#: plugins/sawfish/sawfish-config-gui.c:149
msgid "Information"
msgstr ""

#: plugins/nautilus/nautilus-plugin.c:170
msgid "Nautilus file manager"
msgstr ""

#: plugins/nautilus/nautilus-plugin.c:181
msgid "Nautilus"
msgstr ""

#: plugins/nautilus/nautilus-plugin.c:182
msgid ""
"Nautilus is the GNOME file manager. Nautilus also controls the appearance "
"and behavior of desktop icons."
msgstr ""

#: plugins/sawfish/sawfish-plugin.c:277
msgid "Sawfish Window Manager"
msgstr ""

#: plugins/sawfish/sawfish-plugin.c:286
msgid "Sawfish"
msgstr ""

#: plugins/sawfish/sawfish-plugin.c:287
msgid ""
"Sawfish is a window manager which controls the appearance and behavior of "
"your windows."
msgstr ""

#: plugins/xmms/xmms-plugin.c:173
msgid "XMMS plugin"
msgstr ""

#: plugins/xmms/xmms-plugin.c:188
msgid "XMMS skins"
msgstr ""

#: plugins/xmms/xmms-plugin.c:197
msgid "XMMS"
msgstr ""

#: plugins/xmms/xmms-plugin.c:198
msgid "XMMS is a cross-platform media player."
msgstr ""
